# -*- coding: utf-8 -*-
"""
    Utilitybelt
    ~~~~~

    :copyright: (c) 2014 by Halfmoon Labs
    :license: MIT, see LICENSE for more details.
"""

def is_hex(val):
    if val[0:2] == '0x':
        val = val[2:]
    try:
        int(val, 16)
    except ValueError:
        return False
    else:
        return True

def is_int(val):
    return isinstance(val, (int,long))

def hex_to_int(s):
	try:
		return int(s, 16)
	except:
		raise ValueError("Value must be in hex format")

def int_to_hex(val):
	try:
		return hex(val)[2:]
	except:
		raise ValueError("Value must be in int format")



# -*- coding: utf-8 -*-
"""
    Utilitybelt
    ~~~~~

    :copyright: (c) 2014 by Halfmoon Labs
    :license: MIT, see LICENSE for more details.
"""

__version__ = '0.1.5'

from .dicts import recursive_dict, scrub_dict, to_dict, recursive_dict_to_dict
from .charsets import int_to_charset, charset_to_int, change_charset
from .numbers import is_hex, is_int, hex_to_int, int_to_hex



# -*- coding: utf-8 -*-
"""
    Utilitybelt
    ~~~~~

    :copyright: (c) 2014 by Halfmoon Labs
    :license: MIT, see LICENSE for more details.
"""

import re, string

def int_to_charset(val, charset):
    """ Turn a non-negative integer into a string.
    """
    if not val >= 0:
        raise ValueError('"val" must be a non-negative integer.')
    if val == 0: return charset[0]
    output = ""
    while val > 0:
        val, digit = divmod(val, len(charset))
        output += charset[digit]
    # reverse the characters in the output and return
    return output[::-1]

def charset_to_int(s, charset):
    """ Turn a string into a non-negative integer.
    """
    output = 0
    for char in s:
        output = output * len(charset) + charset.index(char)
    return output

def change_charset(s, original_charset, target_charset):
    """ Convert a string from one charset to another.
    """
    if not isinstance(s, str):
        raise ValueError('"s" must be a string.')

    intermediate_integer = charset_to_int(s, original_charset)
    output_string = int_to_charset(intermediate_integer, target_charset)
    return output_string




"""
Useful Utils
==============

"""

from setuptools import setup, find_packages

setup(
    name='utilitybelt',
    version='0.1.5',
    author='Halfmoon Labs',
    author_email='hello@halfmoonlabs.com',
    description='Generally useful tools.',
    keywords='dict dictionary scrub to_dict todict json characters charset hex',
    url='https://github.com/onenameio/utilitybelt',
    license='MIT',
    packages=find_packages(),
    install_requires=[
    ],
    classifiers=[
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
    ],
    zip_safe=False, 
)
